Module bench

Module bench 

Provides functionality for benchmarking.

Modules

binary
Provides functionality for sourcing binaries of the benchmarking CLI.

Structs

BlockCmd
Benchmark the execution time of historic blocks.
GenesisBuilderPolicyIter
An iterator over the variants of GenesisBuilderPolicy
MachineCmd
Command to benchmark the hardware.
OverheadCmd
Benchmark the execution overhead per-block and per-extrinsic.
StorageCmd
Benchmark the storage speed of a chain snapshot.

Enums

BenchmarkingCliCommand
Commands that can be executed by the frame-benchmarking-cli CLI.
GenesisBuilderPolicy
How the genesis state for benchmarking should be built.

Constants

GENESIS_BUILDER_DEV_PRESET
The default development preset used to communicate with the runtime via GenesisBuilder interface.

Functions

generate_binary_benchmarks
Generates binary benchmarks using frame-benchmarking-cli.
generate_omni_bencher_benchmarks
Run command for benchmarking with a provided frame-omni-bencher binary.
generate_pallet_benchmarks
Runs pallet benchmarks using frame-benchmarking-cli.
get_runtime_path
Get the runtime folder path and throws error if it does not exist.
load_pallet_extrinsics
Loads a mapping of pallets and their associated extrinsics from the runtime binary.

Type Aliases

PalletExtrinsicsRegistry
Type alias for records where the key is the pallet name and the value is an array of its extrinsics.