Provides functionality for sourcing binaries of the benchmarking CLI.
Functions
- omni_
bencher_ generator - Generate the source of the
frame-omni-bencherbinary on the remote repository.
Provides functionality for sourcing binaries of the benchmarking CLI.
frame-omni-bencher binary on the remote repository.