pub enum Action {
Transfer,
CreateAsset,
MintAsset,
CreateCollection,
MintNFT,
PurchaseOnDemandCoretime,
PureProxy,
Reserve,
Register,
Remark,
MapAccount,
}Expand description
Enum representing various predefined actions supported.
Variants
Transfer
Transfer balance.
CreateAsset
Create an asset.
MintAsset
Mint an asset.
CreateCollection
Create a NFT collection.
MintNFT
Mint a NFT.
PurchaseOnDemandCoretime
Purchase on-demand coretime.
PureProxy
Create a pure proxy.
Reserve
Reserve a parachain ID.
Register
Register a parachain ID with genesis state and code.
Remark
Make a remark.
MapAccount
Register the callers account so that it can be used in contract interactions.
Implementations
Sourceimpl Action
impl Action
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Get the description of the action.
Sourcepub fn function_name(&self) -> &str
pub fn function_name(&self) -> &str
Get the dispatchable function name corresponding to the action.
Sourcepub fn pallet_name(&self) -> &str
pub fn pallet_name(&self) -> &str
Get the associated pallet name for the action.