pub enum ChainSpecBuilder {
Node {
node_path: PathBuf,
default_bootnode: bool,
profile: Profile,
},
Runtime {
runtime_path: PathBuf,
profile: Profile,
},
}Expand description
A builder for generating chain specifications.
This enum represents two different ways to build a chain specification:
- Using an existing node.
- Using a runtime.
Variants
Node
A node-based chain specification builder.
Fields
Runtime
A runtime-based chain specification builder.
Implementations
Sourceimpl ChainSpecBuilder
impl ChainSpecBuilder
Sourcepub fn build(
&self,
features: &[String],
redirect_output_to_stderr: bool,
) -> Result<PathBuf>
pub fn build( &self, features: &[String], redirect_output_to_stderr: bool, ) -> Result<PathBuf>
Sourcepub fn path(&self) -> PathBuf
pub fn path(&self) -> PathBuf
Gets the path associated with this chain specification builder.
Returns
The path to either the node or runtime directory.
Sourcepub fn profile(&self) -> Profile
pub fn profile(&self) -> Profile
Gets the build profile associated with this chain specification builder.
Returns
The build profile (debug, release, production, etc.) to use when building the chain.
Sourcepub fn artifact_path(&self) -> Result<PathBuf>
pub fn artifact_path(&self) -> Result<PathBuf>
Gets the path to the built artifact.
Returns
The path to the built artifact (node binary or runtime WASM).
Sourcepub fn generate_plain_chain_spec(
&self,
chain_or_preset: &str,
output_file: &Path,
name: Option<&str>,
id: Option<&str>,
) -> Result<(), Error>
pub fn generate_plain_chain_spec( &self, chain_or_preset: &str, output_file: &Path, name: Option<&str>, id: Option<&str>, ) -> Result<(), Error>
Generates a plain (human readable) chain specification file.
Arguments
chain_or_preset- The chain (when using a node) or preset (when using a runtime) name.output_file- The path where the chain spec should be written.name- The name to be used on the chain spec if specified.id- The ID to be used on the chain spec if specified.
Sourcepub fn generate_raw_chain_spec(
&self,
plain_chain_spec: &Path,
raw_chain_spec_name: &str,
) -> Result<PathBuf, Error>
pub fn generate_raw_chain_spec( &self, plain_chain_spec: &Path, raw_chain_spec_name: &str, ) -> Result<PathBuf, Error>
Sourcepub fn export_wasm_file(
&self,
raw_chain_spec: &Path,
wasm_file_name: &str,
) -> Result<PathBuf, Error>
pub fn export_wasm_file( &self, raw_chain_spec: &Path, wasm_file_name: &str, ) -> Result<PathBuf, Error>
Extracts and exports the WebAssembly runtime code from a raw chain specification.
Arguments
raw_chain_spec- Path to the raw chain specification file to extract the runtime from.wasm_file_name- Name for the file where the extracted runtime will be saved.
Returns
The path to the generated WASM runtime file.
Errors
Returns an error if:
- The chain specification file cannot be read or parsed.
- The runtime cannot be extracted from the chain spec.
- The runtime cannot be written to the output file.