pub enum ChainTemplate {
Standard,
Assets,
Contracts,
OpenZeppelinGeneric,
OpenZeppelinEVM,
ParityGeneric,
}Expand description
Templates supported.
Variants
Standard
Pop Standard Template: Minimalist parachain template.
Assets
Pop Assets Template: Parachain configured with fungible and non-fungible asset functionalities.
Contracts
Pop Contracts Template: Parachain configured to support WebAssembly smart contracts.
OpenZeppelinGeneric
OpenZeppelin Generic Runtime Template: A generic template for Substrate Runtime.
OpenZeppelinEVM
OpenZeppelin EVM Template: Parachain with EVM compatibility out of the box.
ParityGeneric
Parity Generic Template: The Parachain-Ready Template From Polkadot SDK.
Implementations
Sourceimpl ChainTemplate
impl ChainTemplate
Sourcepub fn network_config(&self) -> Option<&str>
pub fn network_config(&self) -> Option<&str>
Returns the relative path to the default network configuration file to be used, if defined.
Sourcepub fn supported_versions(&self) -> Option<Vec<&str>>
pub fn supported_versions(&self) -> Option<Vec<&str>>
The supported versions of the template.
Sourcepub fn is_supported_version(&self, version: &str) -> bool
pub fn is_supported_version(&self, version: &str) -> bool
Sourcepub fn is_audited(&self) -> bool
pub fn is_audited(&self) -> bool
Whether the template has been audited.
Sourcepub fn deployment_name(&self) -> Option<&str>
pub fn deployment_name(&self) -> Option<&str>
Returns the deployment name for the parachain if defined.
Sourcepub fn deployment_name_from_based_on(based_on: &str) -> Option<String>
pub fn deployment_name_from_based_on(based_on: &str) -> Option<String>
Retrieves the deployment name from the based_on value.
Sourcepub fn template_name_without_provider(&self) -> &str
pub fn template_name_without_provider(&self) -> &str
Gets the template name, removing the provider if present.