pub enum Error {
Show 38 variants
Aborted,
AnyhowError(Error),
BuildSpecError(String),
BenchmarkingError(String),
CallDataDecodingError(String),
CallDataEncodingError(String),
CommonError(Error),
ConnectionFailure(String),
Config(String),
CurrentDirAccess,
EndowmentError,
EventNotFound(String),
ExtrinsicSubmissionError(String),
CallableNotSupported,
FunctionNotFound(String),
GenesisBuilderError(String),
ImageTagRetrievalFailed,
IO(Error),
JsonError(Error),
MetadataParsingError(String),
MissingBinary(String),
MissingChainSpec(String),
MissingCommand {
command: String,
binary: String,
},
NetworkConfigurationError(Vec<Error>),
OrchestratorError(OrchestratorError),
PalletDirCreation,
PalletNotFound(String),
ParamProcessingError,
ParamParsingError(String),
PathError,
RustfmtError(Error),
RuntimeNotFound(String),
SourcingError(Error),
SubXtError(Box<Error>),
TomlError(Error),
TryRuntimeError(String),
UnsupportedCommand(String),
WorkspaceLocate,
}Expand description
Represents the various errors that can occur in the crate.
Variants
Aborted
The operation has been aborted due to an existing target directory.
AnyhowError(Error)
An error occurred.
BuildSpecError(String)
An error occurred while generating the chain specification.
BenchmarkingError(String)
An error occurred while running benchmarking.
CallDataDecodingError(String)
An error occurred while decoding the call data.
CallDataEncodingError(String)
An error occurred while encoding the call data.
CommonError(Error)
An error occurred.
ConnectionFailure(String)
An error occurred while attempting to establish a connection to the endpoint.
Config(String)
A configuration error occurred.
CurrentDirAccess
The current directory could not be accessed.
EndowmentError
The endowment value could not be parsed.
EventNotFound(String)
The specified event was not found.
ExtrinsicSubmissionError(String)
An error occurred during the submission of an extrinsic.
CallableNotSupported
The callable item is not supported.
FunctionNotFound(String)
Function not found.
GenesisBuilderError(String)
An error occurred while working with the genesis builder.
ImageTagRetrievalFailed
Failed to retrieve the image tag.
IO(Error)
An IO error occurred.
JsonError(Error)
A JSON error occurred.
MetadataParsingError(String)
An error occurred while parsing metadata of a parameter.
MissingBinary(String)
A binary is missing.
MissingChainSpec(String)
A chain spec is missing.
MissingCommand
A required command does not exist.
NetworkConfigurationError(Vec<Error>)
A network configuration error occurred.
OrchestratorError(OrchestratorError)
An orchestrator error occurred.
PalletDirCreation
The attempt to create a pallet directory failed.
PalletNotFound(String)
The specified pallet could not be found.
ParamProcessingError
An error occurred while processing the arguments provided by the user.
ParamParsingError(String)
An error occurred while parsing the arguments provided by the user.
PathError
The path is invalid.
RustfmtError(Error)
Failed to execute rustfmt.
RuntimeNotFound(String)
The specified runtime could not be found.
SourcingError(Error)
An error occurred sourcing a binary.
SubXtError(Box<Error>)
An error occurred whilst interacting with a chain using subxt.
TomlError(Error)
A TOML error occurred.
TryRuntimeError(String)
An error occurred while testing with try-runtime.
UnsupportedCommand(String)
The command is not supported.
WorkspaceLocate
The workspace could not be located.