build_chain

Function build_chain 

pub fn build_chain(
    path: &Path,
    package: Option<String>,
    profile: &Profile,
    node_path: Option<&Path>,
    features: &[String],
    redirect_output_to_stderr: bool,
) -> Result<PathBuf, Error>
Build the chain and returns the path to the binary.

Arguments

  • path - The path to the chain manifest.
  • package - The optional package to be built.
  • profile - Whether the chain should be built without any debugging functionality.
  • node_path - An optional path to the node directory. Defaults to the node subdirectory of the project path if not provided.
  • features - A set of features the project is built with.