build_project

Function build_project 

pub fn build_project(
    path: &Path,
    package: Option<String>,
    profile: &Profile,
    features: &[String],
    target: Option<&str>,
    redirect_output_to_stderr: bool,
) -> Result<(), Error>
Build the Rust project.

Arguments

  • path - The optional path to the project manifest, defaulting to the current directory if not specified.
  • package - The optional package to be built.
  • profile - Whether the project should be built without any debugging functionality.
  • features - A set of features the project is built with.
  • target - The optional target to be specified.