pub fn construct_sudo_extrinsic(xt: DynamicPayload) -> DynamicPayloadExpand description
Constructs a Sudo extrinsic.
Arguments
xt: The extrinsic representing the dispatchable function call to be dispatched withRootprivileges.
pub fn construct_sudo_extrinsic(xt: DynamicPayload) -> DynamicPayloadConstructs a Sudo extrinsic.
xt: The extrinsic representing the dispatchable function call to be dispatched with Root
privileges.