generate_plain_chain_spec_with_node

Function generate_plain_chain_spec_with_node 

pub fn generate_plain_chain_spec_with_node(
    binary_path: &Path,
    plain_chain_spec: &Path,
    default_bootnode: bool,
    chain: &str,
) -> Result<(), Error>
Generates the plain text chain specification for a chain with its own node.

Arguments

  • binary_path - The path to the node binary executable that contains the build-spec command.
  • plain_chain_spec - Location of the plain_chain_spec file to be generated.
  • default_bootnode - Whether to include localhost as a bootnode.
  • chain - The chain specification. It can be one of the predefined ones (e.g. dev, local or a custom one) or the path to an existing chain spec.