generate_raw_chain_spec_with_node

Function generate_raw_chain_spec_with_node 

pub fn generate_raw_chain_spec_with_node(
    binary_path: &Path,
    plain_chain_spec: &Path,
    chain_spec_file_name: &str,
) -> Result<PathBuf, Error>
Generates a raw chain specification file for a chain.

Arguments

  • binary_path - The path to the node binary executable that contains the build-spec command.
  • plain_chain_spec - Location of the plain chain specification file.
  • chain_spec_file_name - The name of the chain specification file to be generated.