pub fn is_supported(path: &Path) -> boolExpand description
Determines whether the manifest at the supplied path is a supported chain project.
Arguments
path- The optional path to the manifest, defaulting to the current directory if not specified.