parse_chain_metadata

Function parse_chain_metadata 

pub fn parse_chain_metadata(
    client: &OnlineClient<SubstrateConfig>,
) -> Result<Vec<Pallet>, Error>
Parses the chain metadata to extract information about pallets and their dispatchable functions.

Arguments

  • client: The client to interact with the chain.

NOTE: pallets are ordered by their index within the runtime by default.