parse_dispatchable_arguments

Function parse_dispatchable_arguments 

pub fn parse_dispatchable_arguments(
    params: &[Param],
    raw_params: Vec<String>,
) -> Result<Vec<Value>, Error>
Parses and processes raw string parameter values for a dispatchable function, mapping them to Value types.

Arguments

  • params: The metadata definition for each parameter of the corresponding dispatchable function.
  • raw_params: A vector of raw string arguments for the dispatchable function.