runtime_binary_path

Function runtime_binary_path 

pub fn runtime_binary_path(
    target_path: &Path,
    runtime_path: &Path,
) -> Result<PathBuf, Error>
Constructs the runtime binary path based on the target path and the directory path.

Arguments

  • target_path - The path where the binaries are expected to be found.
  • runtime_path - The path to the runtime from which the runtime name will be parsed.