Module omni_node

Module omni_node 

Provides functionality for running runtime-only parachains.

Enums

PolkadotOmniNodeCli
CLI enum for managing Polkadot Omni Node binary sources and configuration. Provides repository information and binary specifications for fetching and managing the node.

Functions

polkadot_omni_node_generator
Generate the source of the polkadot-omni-node binary on the remote repository.