Module runtime

Module runtime 

Build the deterministic runtime.

Structs

DeterministicBuilder
Builds and executes the command for running a deterministic runtime build process using srtool.

Functions

is_supported
Determines whether the manifest at the supplied path is a supported Substrate runtime project.