is_supported

Function is_supported 

pub fn is_supported(path: &Path) -> bool
Determines whether the manifest at the supplied path is a supported Substrate runtime project.

Arguments

  • path - The optional path to the manifest, defaulting to the current directory if not specified.