pub struct ChainSpec(/* private fields */);Expand description
A chain specification.
Implementations
Sourceimpl ChainSpec
impl ChainSpec
Sourcepub fn get_chain_type(&self) -> Option<&str>
pub fn get_chain_type(&self) -> Option<&str>
Get the chain type from the chain specification.
Sourcepub fn get_chain_id(&self) -> Option<u64>
pub fn get_chain_id(&self) -> Option<u64>
Get the chain ID from the chain specification.
Sourcepub fn get_property_based_on(&self) -> Option<&str>
pub fn get_property_based_on(&self) -> Option<&str>
Get the property basedOn from the chain specification.
Sourcepub fn get_protocol_id(&self) -> Option<&str>
pub fn get_protocol_id(&self) -> Option<&str>
Get the protocol ID from the chain specification.
Sourcepub fn get_relay_chain(&self) -> Option<&str>
pub fn get_relay_chain(&self) -> Option<&str>
Get the relay chain from the chain specification.
Sourcepub fn get_sudo_key(&self) -> Option<&str>
pub fn get_sudo_key(&self) -> Option<&str>
Get the sudo key from the chain specification.
Sourcepub fn replace_para_id(&mut self, para_id: u32) -> Result<(), Error>
pub fn replace_para_id(&mut self, para_id: u32) -> Result<(), Error>
Replaces the chain id with the provided para_id.
Arguments
para_id- The new value for the para_id.
Sourcepub fn replace_relay_chain(&mut self, relay_name: &str) -> Result<(), Error>
pub fn replace_relay_chain(&mut self, relay_name: &str) -> Result<(), Error>
Replaces the relay chain name with the given one.
Arguments
relay_name- The new value for the relay chain field in the specification.
Sourcepub fn replace_chain_type(&mut self, chain_type: &str) -> Result<(), Error>
pub fn replace_chain_type(&mut self, chain_type: &str) -> Result<(), Error>
Replaces the chain type with the given one.
Arguments
chain_type- The new value for the chain type.
Sourcepub fn replace_protocol_id(&mut self, protocol_id: &str) -> Result<(), Error>
pub fn replace_protocol_id(&mut self, protocol_id: &str) -> Result<(), Error>
Replaces the protocol ID with the given one.
Arguments
protocol_id- The new value for the protocolId of the given specification.
Sourcepub fn replace_properties(&mut self, raw_properties: &str) -> Result<(), Error>
pub fn replace_properties(&mut self, raw_properties: &str) -> Result<(), Error>
Replaces the properties with the given ones.
Arguments
raw_properties- Comma-separated, key-value pairs. Example: “KEY1=VALUE1,KEY2=VALUE2”.
Sourcepub fn replace_collator_keys(
&mut self,
collator_keys: Vec<String>,
) -> Result<(), Error>
pub fn replace_collator_keys( &mut self, collator_keys: Vec<String>, ) -> Result<(), Error>
Replaces the invulnerables session keys in the chain specification with the provided
collator_keys.
Arguments
collator_keys- A list of new collator keys.