pub struct ExtrinsicEvents<T>where
T: Config,{ /* private fields */ }Expand description
The events associated with a given extrinsic.
Implementations
Sourceimpl<T> ExtrinsicEvents<T>where
T: Config,
impl<T> ExtrinsicEvents<T>where
T: Config,
Sourcepub fn extrinsic_index(&self) -> u32
pub fn extrinsic_index(&self) -> u32
The index of the extrinsic that these events are produced from.
Sourcepub fn extrinsic_hash(&self) -> <<T as Config>::Hasher as Hasher>::Output
pub fn extrinsic_hash(&self) -> <<T as Config>::Hasher as Hasher>::Output
Return the hash of the extrinsic.
Sourcepub fn all_events_in_block(&self) -> &Events<T>
pub fn all_events_in_block(&self) -> &Events<T>
Return all of the events in the block that the extrinsic is in.
Sourcepub fn iter(&self) -> impl Iterator<Item = Result<EventDetails<T>, Error>>
pub fn iter(&self) -> impl Iterator<Item = Result<EventDetails<T>, Error>>
Iterate over all of the raw events associated with this transaction.
This works in the same way that events::Events::iter() does, with the
exception that it filters out events not related to the submitted extrinsic.
Sourcepub fn find<Ev>(&self) -> impl Iterator<Item = Result<Ev, Error>>where
Ev: StaticEvent,
pub fn find<Ev>(&self) -> impl Iterator<Item = Result<Ev, Error>>where
Ev: StaticEvent,
Find all of the transaction events matching the event type provided as a generic parameter.
This works in the same way that events::Events::find() does, with the
exception that it filters out events not related to the submitted extrinsic.
Sourcepub fn find_first<Ev>(&self) -> Result<Option<Ev>, Error>where
Ev: StaticEvent,
pub fn find_first<Ev>(&self) -> Result<Option<Ev>, Error>where
Ev: StaticEvent,
Iterate through the transaction events using metadata to dynamically decode and skip
them, and return the first event found which decodes to the provided Ev type.
This works in the same way that events::Events::find_first() does, with the
exception that it ignores events not related to the submitted extrinsic.
Sourcepub fn find_last<Ev>(&self) -> Result<Option<Ev>, Error>where
Ev: StaticEvent,
pub fn find_last<Ev>(&self) -> Result<Option<Ev>, Error>where
Ev: StaticEvent,
Iterate through the transaction events using metadata to dynamically decode and skip
them, and return the last event found which decodes to the provided Ev type.
This works in the same way that events::Events::find_last() does, with the
exception that it ignores events not related to the submitted extrinsic.
Sourcepub fn has<Ev>(&self) -> Result<bool, Error>where
Ev: StaticEvent,
pub fn has<Ev>(&self) -> Result<bool, Error>where
Ev: StaticEvent,
Find an event in those associated with this transaction. Returns true if it was found.
This works in the same way that events::Events::has() does, with the
exception that it ignores events not related to the submitted extrinsic.