pub struct SharedParams {
pub runtime: Runtime,
pub disable_spec_name_check: bool,
pub wasm_method: WasmExecutionMethod,
pub wasmtime_instantiation_strategy: WasmtimeInstantiationStrategy,
pub export_proof: Option<PathBuf>,
pub overwrite_state_version: Option<StateVersion>,
}Expand description
Shared parameters of the try-runtime commands
Fields
runtime: RuntimeThe runtime to use.
Must be a path to a wasm blob, compiled with try-runtime feature flag.
Or, existing, indicating that you don’t want to overwrite the runtime. This will use
whatever comes from the remote node, or the snapshot file. This will most likely not work
against a remote node, as no (sane) blockchain should compile its onchain wasm with
try-runtime feature.
disable_spec_name_check: boolWhether to disable enforcing the new runtime spec_name matches the existing spec_name.
wasm_method: WasmExecutionMethodType of wasm execution used.
wasmtime_instantiation_strategy: WasmtimeInstantiationStrategyThe WASM instantiation method to use.
Only has an effect when wasm-execution is set to compiled.
export_proof: Option<PathBuf>Path to a file to export the storage proof into (as a JSON).
If several blocks are executed, the path is interpreted as a folder
where one file per block will be written (named {block_number}-{block_hash}).
overwrite_state_version: Option<StateVersion>Overwrite the state_version.
Otherwise remote-externalities will automatically set the correct state version.
Implementations
Sourcepub fn has_argument(arg: &str) -> bool
pub fn has_argument(arg: &str) -> bool
Check if the given argument is a shared parameter.