Module helpers

Module helpers 

Utility functions and helpers for chain operations.

This module contains various utility functions and helpers that are used across the codebase to assist with chain operations, validations, and common tasks.

Functions

get_preset_names
Get genesis builder preset names of the runtime.
is_initial_endowment_valid
Check if the initial endowment input by the user is a valid balance.