pub fn binary_path(
target_path: &Path,
node_path: &Path,
) -> Result<PathBuf, Error>Expand description
Constructs the node binary path based on the target path and the node directory path.
Arguments
target_path- The path where the binaries are expected to be found.node_path- The path to the node from which the node name will be parsed.