pub fn construct_proxy_extrinsic(
pallets: &[Pallet],
proxied_account: String,
xt: DynamicPayload,
) -> Result<DynamicPayload, Error>Expand description
Constructs a Proxy call extrinsic.
Arguments
pallets: List of pallets available within the chain’s runtime.proxied_account- The account on whose behalf the proxy will act.xt: The extrinsic representing the dispatchable function call to be dispatched using the proxy.