export_wasm_file_with_node

Function export_wasm_file_with_node 

pub fn export_wasm_file_with_node(
    binary_path: &Path,
    raw_chain_spec: &Path,
    wasm_file_name: &str,
) -> Result<PathBuf, Error>
Export the WebAssembly runtime for the chain.

Arguments

  • binary_path - The path to the node binary executable that contains the export-genesis-wasm command.
  • raw_chain_spec - Location of the raw chain specification file.
  • wasm_file_name - The name of the wasm runtime file to be generated.