pub fn generate_raw_chain_spec_with_node(
binary_path: &Path,
plain_chain_spec: &Path,
chain_spec_file_name: &str,
) -> Result<PathBuf, Error>Expand description
Generates a raw chain specification file for a chain.
Arguments
binary_path- The path to the node binary executable that contains thebuild-speccommand.plain_chain_spec- Location of the plain chain specification file.chain_spec_file_name- The name of the chain specification file to be generated.