Provides functionality for running runtime-only parachains.
Enums
- Polkadot
Omni Node Cli - CLI enum for managing Polkadot Omni Node binary sources and configuration. Provides repository information and binary specifications for fetching and managing the node.
Functions
- polkadot_
omni_ node_ generator - Generate the source of the
polkadot-omni-nodebinary on the remote repository.