Build the deterministic runtime.
Structs
- Deterministic
Builder - Builds and executes the command for running a deterministic runtime build process using srtool.
Enums
- Container
Engine - Represents the container engine being used.
Functions
- get_
image_ digest - get_
image_ tag - Get the latest image. it is fetched from cache we have a version that is younger than
cache_validityin seconds. - is_
supported - Determines whether the manifest at the supplied path is a supported Substrate runtime project.