Module runtime

Module runtime 

Build the deterministic runtime.

Structs

DeterministicBuilder
Builds and executes the command for running a deterministic runtime build process using srtool.

Enums

ContainerEngine
Represents the container engine being used.

Functions

get_image_digest
get_image_tag
Get the latest image. it is fetched from cache we have a version that is younger than cache_validity in seconds.
is_supported
Determines whether the manifest at the supplied path is a supported Substrate runtime project.