pub struct OnlineClient<T>where
T: Config,{ /* private fields */ }Expand description
A client that can be used to perform API calls (that is, either those
requiring an OfflineClientT or those requiring an OnlineClientT).
Implementations
Sourceimpl<T> OnlineClient<T>where
T: Config,
impl<T> OnlineClient<T>where
T: Config,
Sourcepub async fn new() -> Result<OnlineClient<T>, Error>
pub async fn new() -> Result<OnlineClient<T>, Error>
Construct a new OnlineClient using default settings which
point to a locally running node on ws://127.0.0.1:9944.
Sourcepub async fn from_url(url: impl AsRef<str>) -> Result<OnlineClient<T>, Error>
pub async fn from_url(url: impl AsRef<str>) -> Result<OnlineClient<T>, Error>
Construct a new OnlineClient, providing a URL to connect to.
Sourcepub async fn from_insecure_url(
url: impl AsRef<str>,
) -> Result<OnlineClient<T>, Error>
pub async fn from_insecure_url( url: impl AsRef<str>, ) -> Result<OnlineClient<T>, Error>
Construct a new OnlineClient, providing a URL to connect to.
Allows insecure URLs without SSL encryption, e.g. (http:// and ws:// URLs).
Sourceimpl<T> OnlineClient<T>where
T: Config,
impl<T> OnlineClient<T>where
T: Config,
Sourcepub async fn from_rpc_client(
rpc_client: impl Into<RpcClient>,
) -> Result<OnlineClient<T>, Error>
pub async fn from_rpc_client( rpc_client: impl Into<RpcClient>, ) -> Result<OnlineClient<T>, Error>
Construct a new OnlineClient by providing an RpcClient to drive the connection.
This will use the current default Backend, which may change in future releases.
Sourcepub fn from_rpc_client_with(
genesis_hash: <<T as Config>::Hasher as Hasher>::Output,
runtime_version: RuntimeVersion,
metadata: impl Into<Metadata>,
rpc_client: impl Into<RpcClient>,
) -> Result<OnlineClient<T>, Error>
pub fn from_rpc_client_with( genesis_hash: <<T as Config>::Hasher as Hasher>::Output, runtime_version: RuntimeVersion, metadata: impl Into<Metadata>, rpc_client: impl Into<RpcClient>, ) -> Result<OnlineClient<T>, Error>
Construct a new OnlineClient by providing an RPC client along with the other
necessary details. This will use the current default Backend, which may change
in future releases.
Warning
This is considered the most primitive and also error prone way to instantiate a client; the genesis hash, metadata and runtime version provided will entirely determine which node and blocks this client will be able to interact with, and whether it will be able to successfully do things like submit transactions.
If you’re unsure what you’re doing, prefer one of the alternate methods to instantiate a client.
Sourcepub async fn from_backend<B>(backend: Arc<B>) -> Result<OnlineClient<T>, Error>where
B: Backend<T>,
pub async fn from_backend<B>(backend: Arc<B>) -> Result<OnlineClient<T>, Error>where
B: Backend<T>,
Construct a new OnlineClient by providing an underlying Backend
implementation to power it. Other details will be obtained from the chain.
Sourcepub fn from_backend_with<B>(
genesis_hash: <<T as Config>::Hasher as Hasher>::Output,
runtime_version: RuntimeVersion,
metadata: impl Into<Metadata>,
backend: Arc<B>,
) -> Result<OnlineClient<T>, Error>where
B: Backend<T>,
pub fn from_backend_with<B>(
genesis_hash: <<T as Config>::Hasher as Hasher>::Output,
runtime_version: RuntimeVersion,
metadata: impl Into<Metadata>,
backend: Arc<B>,
) -> Result<OnlineClient<T>, Error>where
B: Backend<T>,
Construct a new OnlineClient by providing all of the underlying details needed
to make it work.
Warning
This is considered the most primitive and also error prone way to instantiate a client; the genesis hash, metadata and runtime version provided will entirely determine which node and blocks this client will be able to interact with, and whether it will be able to successfully do things like submit transactions.
If you’re unsure what you’re doing, prefer one of the alternate methods to instantiate a client.
Sourcepub fn updater(&self) -> ClientRuntimeUpdater<T>
pub fn updater(&self) -> ClientRuntimeUpdater<T>
Create an object which can be used to keep the runtime up to date in a separate thread.
Example
use subxt::{ OnlineClient, PolkadotConfig };
let client = OnlineClient::<PolkadotConfig>::new().await.unwrap();
// high level API.
let update_task = client.updater();
tokio::spawn(async move {
update_task.perform_runtime_updates().await;
});
// low level API.
let updater = client.updater();
tokio::spawn(async move {
let mut update_stream = updater.runtime_updates().await.unwrap();
while let Some(Ok(update)) = update_stream.next().await {
let version = update.runtime_version().spec_version;
match updater.apply_update(update) {
Ok(()) => {
println!("Upgrade to version: {} successful", version)
}
Err(e) => {
println!("Upgrade to version {} failed {:?}", version, e);
}
};
}
});Sourcepub fn hasher(&self) -> <T as Config>::Hasher
pub fn hasher(&self) -> <T as Config>::Hasher
Return the hasher configured for hashing blocks and extrinsics.
Sourcepub fn set_metadata(&self, metadata: impl Into<Metadata>)
pub fn set_metadata(&self, metadata: impl Into<Metadata>)
Sourcepub fn genesis_hash(&self) -> <<T as Config>::Hasher as Hasher>::Output
pub fn genesis_hash(&self) -> <<T as Config>::Hasher as Hasher>::Output
Return the genesis hash.
Sourcepub fn set_genesis_hash(
&self,
genesis_hash: <<T as Config>::Hasher as Hasher>::Output,
)
pub fn set_genesis_hash( &self, genesis_hash: <<T as Config>::Hasher as Hasher>::Output, )
Change the genesis hash used in this client.
Warning
Setting a custom genesis hash may leave Subxt unable to submit valid transactions.
Sourcepub fn runtime_version(&self) -> RuntimeVersion
pub fn runtime_version(&self) -> RuntimeVersion
Return the runtime version.
Sourcepub fn set_runtime_version(&self, runtime_version: RuntimeVersion)
pub fn set_runtime_version(&self, runtime_version: RuntimeVersion)
Change the RuntimeVersion used in this client.
Warning
Setting a custom runtime version may leave Subxt unable to submit valid transactions.
Sourcepub fn backend(&self) -> &(dyn Backend<T> + 'static)
pub fn backend(&self) -> &(dyn Backend<T> + 'static)
Return an RPC client to make raw requests with.
Sourcepub fn offline(&self) -> OfflineClient<T>
pub fn offline(&self) -> OfflineClient<T>
Return an offline client with the same configuration as this.
Sourcepub fn tx(&self) -> TxClient<T, OnlineClient<T>>
pub fn tx(&self) -> TxClient<T, OnlineClient<T>>
Work with transactions.
Sourcepub fn events(&self) -> EventsClient<T, OnlineClient<T>>
pub fn events(&self) -> EventsClient<T, OnlineClient<T>>
Work with events.
Sourcepub fn storage(&self) -> StorageClient<T, OnlineClient<T>>
pub fn storage(&self) -> StorageClient<T, OnlineClient<T>>
Work with storage.
Sourcepub fn constants(&self) -> ConstantsClient<T, OnlineClient<T>>
pub fn constants(&self) -> ConstantsClient<T, OnlineClient<T>>
Access constants.
Sourcepub fn blocks(&self) -> BlocksClient<T, OnlineClient<T>>
pub fn blocks(&self) -> BlocksClient<T, OnlineClient<T>>
Work with blocks.
Sourcepub fn runtime_api(&self) -> RuntimeApiClient<T, OnlineClient<T>>
pub fn runtime_api(&self) -> RuntimeApiClient<T, OnlineClient<T>>
Work with runtime API.
Sourcepub fn view_functions(&self) -> ViewFunctionsClient<T, OnlineClient<T>>
pub fn view_functions(&self) -> ViewFunctionsClient<T, OnlineClient<T>>
Work with View Functions.
Sourcepub fn custom_values(&self) -> CustomValuesClient<T, OnlineClient<T>>
pub fn custom_values(&self) -> CustomValuesClient<T, OnlineClient<T>>
Access custom types.