Utility functions and helpers for chain operations.
This module contains various utility functions and helpers that are used across the codebase to assist with chain operations, validations, and common tasks.
Functions
- get_
preset_ names - Get genesis builder preset names of the runtime.
- is_
initial_ endowment_ valid - Check if the initial endowment input by the user is a valid balance.